==> search-all-2.10.11.tgz: package/README.md <==
Finds indices of values passing a test. [:running:] [:vhs:] [:package:] [:moon:] [:ledger:]

> Alternatives: [search], [searchRight], [searchAll].<br>
> Similar: [search], [scan], [find].

> This is part of package [extra-array].

[extra-array]: https://www.npmjs.com/package/extra-array

<br>

```javascript
array.searchAll(x, ft);
// x:  an array
// ft: test function (v, i, x)
```

```javascript
const array = require('extra-array');

var x = [1, 2, 3, 2, 5];
array.searchAll(x, 2);
// [ 1, 3 ] ^     ^

var x = [1, 2, 3, -2, 5];
array.searchAll(x, 2, (a, b) => Math.abs(a) - Math.abs(b));
// [ 1, 3 ] ^      ^

array.searchAll(x, 2, null, v => Math.abs(v));
// [ 1, 3 ] ^      ^
```

<br>
<br>


## References

- [List-Extra.elemIndices: elm](https://package.elm-lang.org/packages/elm-community/list-extra/7.1.0/List-Extra#elemIndices)
- [iterable-binsearch: @krisselden](https://www.npmjs.com/package/iterable-binsearch)
- [binarysearch: @soldair](https://www.npmjs.com/package/binarysearch)

[:running:]: https://npm.runkit.com/@extra-array/search-all
[:package:]: https://www.npmjs.com/package/@extra-array/search-all
[:moon:]: https://www.npmjs.com/package/@extra-array/search-all.min
[:ledger:]: https://unpkg.com/@extra-array/search-all/
[search]: https://github.com/nodef/extra-array/wiki/search
[searchRight]: https://github.com/nodef/extra-array/wiki/searchRight
[searchAll]: https://github.com/nodef/extra-array/wiki/searchAll
[:vhs:]: https://asciinema.org/a/332123
[scan]: https://github.com/nodef/extra-array/wiki/scan
[find]: https://github.com/nodef/extra-array/wiki/find

==> search-all-2.10.12.tgz: package/README.md <==
Finds indices of values passing a test. [:running:] [:vhs:] [:package:] [:moon:] [:ledger:]

> Alternatives: [search], [searchRight], [searchAll].<br>
> Similar: [search], [scan], [find].

> This is part of package [extra-array].

[extra-array]: https://www.npmjs.com/package/extra-array

<br>

```javascript
array.searchAll(x, ft);
// x:  an array
// ft: test function (v, i, x)
```

```javascript
const array = require("extra-array");

var x = [1, 2, 3, 2, 5];
array.searchAll(x, 2);
// [ 1, 3 ] ^     ^

var x = [1, 2, 3, -2, 5];
array.searchAll(x, 2, (a, b) => Math.abs(a) - Math.abs(b));
// [ 1, 3 ] ^      ^

array.searchAll(x, 2, null, v => Math.abs(v));
// [ 1, 3 ] ^      ^
```

<br>
<br>


## References

- [List-Extra.elemIndices: elm](https://package.elm-lang.org/packages/elm-community/list-extra/7.1.0/List-Extra#elemIndices)
- [iterable-binsearch: @krisselden](https://www.npmjs.com/package/iterable-binsearch)
- [binarysearch: @soldair](https://www.npmjs.com/package/binarysearch)

[:running:]: https://npm.runkit.com/@extra-array/search-all
[:package:]: https://www.npmjs.com/package/@extra-array/search-all
[:moon:]: https://www.npmjs.com/package/@extra-array/search-all.min
[:ledger:]: https://unpkg.com/@extra-array/search-all/
[search]: https://github.com/nodef/extra-array/wiki/search
[searchRight]: https://github.com/nodef/extra-array/wiki/searchRight
[searchAll]: https://github.com/nodef/extra-array/wiki/searchAll
[:vhs:]: https://asciinema.org/a/332123
[scan]: https://github.com/nodef/extra-array/wiki/scan
[find]: https://github.com/nodef/extra-array/wiki/find
